@@ -13,6 +13,7 @@ var length = fs.statSync(file).size
 var string = fs.readFileSync(file, 'utf8')
 
 // Add Promise to mocha's global list
+// eslint-disable-next-line no-self-assign
 global.Promise = global.Promise
 
 describe('Raw Body', function () {
@@ -27,7 +28,7 @@ describe('Raw Body', function () {
   it('should work with `true` as an option', function (done) {
     getRawBody(createStream(), true, function (err, buf) {
       assert.ifError(err)
-      assert.equal(typeof buf, 'string')
+      assert.strictEqual(typeof buf, 'string')
       done()
     })
   })
@@ -56,7 +57,7 @@ describe('Raw Body', function () {
       encoding: true
     }, function (err, str) {
       assert.ifError(err)
-      assert.equal(str, '')
+      assert.strictEqual(str, '')
       done()
     })
 
@@ -101,13 +102,13 @@ describe('Raw Body', function () {
       length: length,
       limit: length - 1
     }, function (err, buf) {
-      assert.equal(err.status, 413)
-      assert.equal(err.statusCode, 413)
-      assert.equal(err.expected, length)
-      assert.equal(err.length, length)
-      assert.equal(err.limit, length - 1)
-      assert.equal(err.type, 'entity.too.large')
-      assert.equal(err.message, 'request entity too large')
+      assert.strictEqual(err.status, 413)
+      assert.strictEqual(err.statusCode, 413)
+      assert.strictEqual(err.expected, length)
+      assert.strictEqual(err.length, length)
+      assert.strictEqual(err.limit, length - 1)
+      assert.strictEqual(err.type, 'entity.too.large')
+      assert.strictEqual(err.message, 'request entity too large')
       done()
     })
   })
@@ -121,7 +122,7 @@ describe('Raw Body', function () {
       limit: 1
     }, function (err, buf) {
       assert.ifError(err)
-      assert.equal(buf.length, 0)
+      assert.strictEqual(buf.length, 0)
       done()
     })
 
@@ -136,7 +137,7 @@ describe('Raw Body', function () {
       length: 1,
       limit: 2
     }, function (err, buf) {
-      assert.equal(err.status, 400)
+      assert.strictEqual(err.status, 400)
       done()
     })
 
@@ -147,7 +148,7 @@ describe('Raw Body', function () {
     getRawBody(createStream(), {
       limit: length - 1
     }, function (err, buf) {
-      assert.equal(err.status, 413)
+      assert.strictEqual(err.status, 413)
       done()
     })
   })
@@ -156,7 +157,7 @@ describe('Raw Body', function () {
     getRawBody(createStream(), {
       length: length - 1
     }, function (err, buf) {
-      assert.equal(err.status, 400)
+      assert.strictEqual(err.status, 400)
       done()
     })
   })
@@ -184,7 +185,7 @@ describe('Raw Body', function () {
     }, function (err, buf) {
       if (err) return done(err)
       assert.ok(buf)
-      assert.equal(buf.length, 13)
+      assert.strictEqual(buf.length, 13)
       done()
     })
   })
@@ -196,7 +197,7 @@ describe('Raw Body', function () {
     stream.setEncoding('utf8')
 
     getRawBody(stream, function (err, buf) {
-      assert.equal(err.status, 500)
+      assert.strictEqual(err.status, 500)
       done()
     })
   })
@@ -208,9 +209,9 @@ describe('Raw Body', function () {
 
     getRawBody(stream, 'akljsdflkajsdf', function (err) {
       assert.ok(err)
-      assert.equal(err.message, 'specified encoding unsupported')
-      assert.equal(err.status, 415)
-      assert.equal(err.type, 'encoding.unsupported')
+      assert.strictEqual(err.message, 'specified encoding unsupported')
+      assert.strictEqual(err.status, 415)
+      assert.strictEqual(err.type, 'encoding.unsupported')
       done()
     })
   })
@@ -234,7 +235,7 @@ describe('Raw Body', function () {
         length: length,
         limit: length - 1
       }).then(throwExpectedError, function (err) {
-        assert.equal(err.status, 413)
+        assert.strictEqual(err.status, 413)
       })
     })
   })
@@ -277,7 +278,7 @@ describe('Raw Body', function () {
         encoding: 'utf-8'
       }, function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -287,7 +288,7 @@ describe('Raw Body', function () {
         encoding: true
       }, function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -295,7 +296,7 @@ describe('Raw Body', function () {
     it('should handle encoding as options string', function (done) {
       getRawBody(createStream(), 'utf-8', function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -305,7 +306,7 @@ describe('Raw Body', function () {
       var string = '¿Cómo estás?'
       getRawBody(stream, 'iso-8859-1', function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -315,7 +316,7 @@ describe('Raw Body', function () {
       var string = '¿Cómo estás?'
       getRawBody(stream, 'utf-8', function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -326,7 +327,7 @@ describe('Raw Body', function () {
       var string = '¿Cómo estás?'
       getRawBody(stream, 'utf-16', function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -337,7 +338,7 @@ describe('Raw Body', function () {
       var string = '¿Cómo estás?'
       getRawBody(stream, 'utf-16', function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -348,7 +349,7 @@ describe('Raw Body', function () {
       var string = '¿Cómo estás?'
       getRawBody(stream, 'utf-16le', function (err, str) {
         assert.ifError(err)
-        assert.equal(str, string)
+        assert.strictEqual(str, string)
         done()
       })
     })
@@ -371,7 +372,7 @@ describe('Raw Body', function () {
       length: 19
     }, function (err, value) {
       assert.ifError(err)
-      assert.equal(value, 'foobar,foobaz,yay!!')
+      assert.strictEqual(value, 'foobar,foobaz,yay!!')
       done()
     })
 
@@ -386,13 +387,13 @@ describe('Raw Body', function () {
 
 function checkBuffer (buf) {
   assert.ok(Buffer.isBuffer(buf))
-  assert.equal(buf.length, length)
-  assert.equal(buf.toString('utf8'), string)
+  assert.strictEqual(buf.length, length)
+  assert.strictEqual(buf.toString('utf8'), string)
 }
 
 function checkString (str) {
   assert.ok(typeof str === 'string')
-  assert.equal(str, string)
+  assert.strictEqual(str, string)
 }
 
 function createStream (buf) {
